@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,11 +20,12 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 Auth Views
 """
 
+from __future__ import unicode_literals
+
 from pyramid.httpexceptions import HTTPFound
 from pyramid.security import remember, forget, authenticated_userid
 
@@ -36,7 +36,8 @@ import formencode
 from pyramid_simpleform import Form
 from ..forms.simpleform import FormRenderer
 
-import edbob
+from rattail.time import localtime
+
 from ..db import Session
 from rattail.db.auth import authenticate_user, set_user_password
 
@@ -85,20 +86,13 @@ def login(request):
                                  form.data['username'],
                                  form.data['password'])
         if user:
-            request.session.flash("%s logged in at %s" % (
-                    user.display_name,
-                    edbob.local_time().strftime('%I:%M %p')))
+            request.session.flash("{0} logged in at {1}".format(
+                    user, localtime(request.rattail_config).strftime('%I:%M %p')))
             headers = remember(request, user.uuid)
             return HTTPFound(location=referrer, headers=headers)
         request.session.flash("Invalid username or password")
 
-    url = request.rattail_config.get('edbob.pyramid', 'login.logo_url',
-                           default=request.static_url('edbob.pyramid:static/img/logo.jpg'))
-    kwargs = eval(request.rattail_config.get('edbob.pyramid', 'login.logo_kwargs',
-                                   default="dict(width=500)"))
-
-    return {'form': FormRenderer(form), 'referrer': referrer,
-            'logo_url': url, 'logo_kwargs': kwargs}
+    return {'form': FormRenderer(form), 'referrer': referrer}
 
 
 def logout(request):
