@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,18 +20,18 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 Core Batch Views
 """
 
+from __future__ import unicode_literals
+
 from pyramid.httpexceptions import HTTPFound
 from pyramid.renderers import render_to_response
 
 from webhelpers.html import tags
 
-from edbob.pyramid.forms import PrettyDateTimeFieldRenderer
-from ...forms import EnumFieldRenderer
+from tailbone.forms import DateTimeFieldRenderer, EnumFieldRenderer
 from ...grids.search import BooleanSearchFilter
 from .. import SearchableAlchemyGridView, CrudView, View
 from ...progress import SessionProgress
@@ -86,7 +85,6 @@ class BatchesGrid(SearchableAlchemyGridView):
 
     def grid(self):
         g = self.make_grid()
-        g.executed.set(renderer=PrettyDateTimeFieldRenderer(from_='utc'))
         g.configure(
             include=[
                 g.source,
@@ -94,7 +92,7 @@ class BatchesGrid(SearchableAlchemyGridView):
                 g.destination,
                 g.description,
                 g.rowcount.label("Row Count"),
-                g.executed,
+                g.executed.with_renderer(DateTimeFieldRenderer(self.request.rattail_config)),
                 ],
             readonly=True)
         if self.request.has_perm('batches.read'):
@@ -121,7 +119,6 @@ class BatchCrud(CrudView):
     def fieldset(self, model):
         fs = self.make_fieldset(model)
         fs.action_type.set(renderer=EnumFieldRenderer(enum.BATCH_ACTION))
-        fs.executed.set(renderer=PrettyDateTimeFieldRenderer(from_='utc'))
         fs.configure(
             include=[
                 fs.source,
@@ -130,7 +127,7 @@ class BatchCrud(CrudView):
                 fs.action_type,
                 fs.description,
                 fs.rowcount.label("Row Count").readonly(),
-                fs.executed.readonly(),
+                fs.executed.with_renderer(DateTimeFieldRenderer(self.request.rattail_config)).readonly(),
                 ])
         return fs
 
