@@ -25,12 +25,14 @@
 Customer Views
 """
 
-from sqlalchemy import and_
+import re
 
-from . import SearchableAlchemyGridView, CrudView
-from ..forms import EnumFieldRenderer
+from sqlalchemy import func, and_
+from sqlalchemy.orm import joinedload
 
-from ..db import Session
+from tailbone.views import SearchableAlchemyGridView, CrudView, AutocompleteView
+from tailbone.forms import EnumFieldRenderer
+from tailbone.db import Session
 
 from rattail import enum
 from rattail.db import model
@@ -133,12 +135,67 @@ class CustomerCrud(CrudView):
         return fs
 
 
+class CustomerNameAutocomplete(AutocompleteView):
+    """
+    Autocomplete view which operates on customer name.
+    """
+    mapped_class = model.Customer
+    fieldname = u'name'
+
+
+class CustomerPhoneAutocomplete(AutocompleteView):
+    """
+    Autocomplete view which operates on customer phone number.
+
+    .. note::
+       As currently implemented, this view will only work with a PostgreSQL
+       database.  It normalizes the user's search term and the database values
+       to numeric digits only (i.e. removes special characters from each) in
+       order to be able to perform smarter matching.  However normalizing the
+       database value currently uses the PG SQL ``regexp_replace()`` function.
+    """
+    invalid_pattern = re.compile(ur'\D')
+
+    def prepare_term(self, term):
+        return self.invalid_pattern.sub(u'', term)
+
+    def query(self, term):
+        return Session.query(model.CustomerPhoneNumber)\
+            .filter(func.regexp_replace(model.CustomerPhoneNumber.number, ur'\D', u'', u'g').like(u'%{0}%'.format(term)))\
+            .order_by(model.CustomerPhoneNumber.number)\
+            .options(joinedload(model.CustomerPhoneNumber.customer))
+
+    def display(self, phone):
+        return u"{0} {1}".format(phone.number, phone.customer)
+
+    def value(self, phone):
+        return phone.customer.uuid
+
+
+def customer_info(request):
+    """
+    View which returns simple dictionary of info for a particular customer.
+    """
+    uuid = request.params.get(u'uuid')
+    customer = Session.query(model.Customer).get(uuid) if uuid else None
+    if not customer:
+        return {}
+    return {
+        u'uuid':                customer.uuid,
+        u'name':                customer.name,
+        u'phone_number':        customer.phone.number if customer.phone else u'',
+        }
+
+
 def add_routes(config):
-    config.add_route('customers',       '/customers')
-    config.add_route('customer.create', '/customers/new')
-    config.add_route('customer.read',   '/customers/{uuid}')
-    config.add_route('customer.update', '/customers/{uuid}/edit')
-    config.add_route('customer.delete', '/customers/{uuid}/delete')
+    config.add_route(u'customers',                      u'/customers')
+    config.add_route(u'customer.create',                u'/customers/new')
+    config.add_route(u'customer.info',                  u'/customers/info')
+    config.add_route(u'customers.autocomplete',         u'/customers/autocomplete')
+    config.add_route(u'customers.autocomplete.phone',   u'/customers/autocomplete/phone')
+    config.add_route(u'customer.read',                  u'/customers/{uuid}')
+    config.add_route(u'customer.update',                u'/customers/{uuid}/edit')
+    config.add_route(u'customer.delete',                u'/customers/{uuid}/delete')
 
 
 def includeme(config):
@@ -147,6 +204,7 @@ def includeme(config):
     config.add_view(CustomersGrid, route_name='customers',
                     renderer='/customers/index.mako',
                     permission='customers.list')
+
     config.add_view(CustomerCrud, attr='create', route_name='customer.create',
                     renderer='/customers/crud.mako',
                     permission='customers.create')
@@ -158,3 +216,14 @@ def includeme(config):
                     permission='customers.update')
     config.add_view(CustomerCrud, attr='delete', route_name='customer.delete',
                     permission='customers.delete')
+
+    config.add_view(CustomerNameAutocomplete, route_name=u'customers.autocomplete',
+                    renderer=u'json',
+                    permission=u'customers.list')
+    config.add_view(CustomerPhoneAutocomplete, route_name=u'customers.autocomplete.phone',
+                    renderer=u'json',
+                    permission=u'customers.list')
+
+    config.add_view(customer_info, route_name=u'customer.info',
+                    renderer=u'json',
+                    permission=u'customers.read')
