@@ -141,7 +141,7 @@ def printer_settings(request):
     read_profile = HTTPFound(location=request.route_url(
             'label_profile.read', uuid=profile.uuid))
 
-    printer = profile.get_printer()
+    printer = profile.get_printer(request.rattail_config)
     if not printer:
         request.session.flash("Label profile \"%s\" does not have a functional "
                               "printer spec." % profile)
