@@ -31,6 +31,8 @@ from sqlalchemy import and_
 from . import SearchableAlchemyGridView, CrudView, AutocompleteView
 
 from ..db import Session
+
+from rattail.db import model
 from rattail.db.model import (Person, PersonEmailAddress, PersonPhoneNumber,
                               VendorContact)
 
@@ -132,9 +134,20 @@ class PeopleAutocomplete(AutocompleteView):
     fieldname = 'display_name'
 
 
+class PeopleEmployeesAutocomplete(PeopleAutocomplete):
+    """
+    Autocomplete view for the Person model, but restricted to return only
+    results for people who are employees.
+    """
+
+    def filter_query(self, q):
+        return q.join(model.Employee)
+
+
 def add_routes(config):
     config.add_route('people',                  '/people')
     config.add_route('people.autocomplete',     '/people/autocomplete')
+    config.add_route(u'people.autocomplete.employees',  u'/people/autocomplete/employees')
     config.add_route('person.read',             '/people/{uuid}')
     config.add_route('person.update',           '/people/{uuid}/edit')
 
@@ -142,15 +155,23 @@ def add_routes(config):
 def includeme(config):
     add_routes(config)
 
+    # List
     config.add_view(PeopleGrid, route_name='people',
                     renderer='/people/index.mako',
                     permission='people.list')
+
+    # CRUD
     config.add_view(PersonCrud, attr='read', route_name='person.read',
                     renderer='/people/crud.mako',
                     permission='people.read')
     config.add_view(PersonCrud, attr='update', route_name='person.update',
                     renderer='/people/crud.mako',
                     permission='people.update')
+
+    # Autocomplete
     config.add_view(PeopleAutocomplete, route_name='people.autocomplete',
                     renderer='json',
                     permission='people.list')
+    config.add_view(PeopleEmployeesAutocomplete, route_name=u'people.autocomplete.employees',
+                    renderer=u'json',
+                    permission=u'people.list')
